@@ -175,7 +175,7 @@ class BaseNodeDisplay(Generic[NodeType], metaclass=BaseNodeDisplayMeta):
 
             adornment: JsonObject = {
                 "id": str(node_id),
-                "label": node.__qualname__,
+                "label": self.label,
                 "base": self.get_base().dict(),
                 "attributes": attributes,
             }
@@ -183,8 +183,6 @@ class BaseNodeDisplay(Generic[NodeType], metaclass=BaseNodeDisplayMeta):
             existing_adornments = adornments if adornments is not None else []
             return display_class().serialize(display_context, adornments=existing_adornments + [adornment])
 
-        ports = self.serialize_ports(display_context)
-
         outputs: JsonArray = []
         for output in node.Outputs:
             type = primitive_type_to_vellum_variable_type(output)
@@ -205,16 +203,9 @@ class BaseNodeDisplay(Generic[NodeType], metaclass=BaseNodeDisplayMeta):
 
         return {
             "id": str(node_id),
-            "label": node.__qualname__,
+            "label": self.label,
             "type": "GENERIC",
-            "display_data": self.get_display_data().dict(),
-            "base": self.get_base().dict(),
-            "definition": self.get_definition().dict(),
-            "trigger": {
-                "id": str(self.get_target_handle_id()),
-                "merge_behavior": node.Trigger.merge_behavior.value,
-            },
-            "ports": ports,
+            **self.serialize_generic_fields(display_context),
             "adornments": adornments,
             "attributes": attributes,
             "outputs": outputs,
@@ -247,6 +238,14 @@ class BaseNodeDisplay(Generic[NodeType], metaclass=BaseNodeDisplayMeta):
 
         return ports
 
+    def serialize_trigger(self) -> JsonObject:
+        """Serialize the trigger of the node."""
+        node = self._node
+        return {
+            "id": str(self.get_target_handle_id()),
+            "merge_behavior": node.Trigger.merge_behavior.value,
+        }
+
     def _serialize_attributes(self, display_context: "WorkflowDisplayContext") -> JsonArray:
         """Serialize node attributes, skipping unserializable ones."""
         attributes: JsonArray = []
@@ -271,6 +270,16 @@ class BaseNodeDisplay(Generic[NodeType], metaclass=BaseNodeDisplayMeta):
 
         return attributes
 
+    def serialize_generic_fields(self, display_context: "WorkflowDisplayContext") -> JsonObject:
+        """Serialize generic fields that are common to all nodes."""
+        return {
+            "display_data": self.get_display_data().dict(),
+            "base": self.get_base().dict(),
+            "definition": self.get_definition().dict(),
+            "trigger": self.serialize_trigger(),
+            "ports": self.serialize_ports(display_context),
+        }
+
     def get_base(self) -> CodeResourceDefinition:
         node = self._node
 
@@ -417,8 +426,8 @@ class BaseNodeDisplay(Generic[NodeType], metaclass=BaseNodeDisplayMeta):
         if explicit_value and explicit_value.comment and docstring:
             comment = (
                 NodeDisplayComment(value=docstring, expanded=explicit_value.comment.expanded)
-                if explicit_value.comment.expanded
-                else NodeDisplayComment(value=docstring)
+                if explicit_value.comment.expanded is not None
+                else NodeDisplayComment(value=docstring, expanded=True)
             )
             return NodeDisplayData(
                 position=explicit_value.position,
@@ -432,7 +441,7 @@ class BaseNodeDisplay(Generic[NodeType], metaclass=BaseNodeDisplayMeta):
 
         if docstring:
             return NodeDisplayData(
-                comment=NodeDisplayComment(value=docstring),
+                comment=NodeDisplayComment(value=docstring, expanded=True),
             )
 
         return NodeDisplayData()
