@@ -129,7 +129,7 @@ def test_serialize_workflow():
                         },
                         {
                             "id": "1381c078-efa2-4255-89a1-7b4cb742c7fc",
-                            "label": "StartNode",
+                            "label": "Start Node",
                             "type": "GENERIC",
                             "display_data": {"position": {"x": 200.0, "y": -50.0}},
                             "base": {"name": "BaseNode", "module": ["vellum", "workflows", "nodes", "bases", "base"]},
@@ -324,6 +324,10 @@ def test_serialize_workflow():
                 "name": "ExampleInlineSubworkflowNode",
                 "module": ["tests", "workflows", "basic_inline_subworkflow", "workflow"],
             },
+            "trigger": {
+                "id": "859a75a6-1bd2-4350-9509-4af66245e8e4",
+                "merge_behavior": "AWAIT_ATTRIBUTES",
+            },
             "ports": [{"id": "cfd831bc-ee7f-44d0-8d76-0ba0cd0277dc", "name": "default", "type": "DEFAULT"}],
         },
         subworkflow_node,
