@@ -40,11 +40,14 @@ def test_serialize_workflow():
     tool_calling_node = workflow_raw_data["nodes"][1]
     assert tool_calling_node == {
         "id": "21f29cac-da87-495f-bba1-093d423f4e46",
-        "label": "GetCurrentWeatherNode",
+        "label": "Get Current Weather Node",
         "type": "GENERIC",
         "display_data": {
             "position": {"x": 200.0, "y": -50.0},
-            "comment": {"value": "\n    A tool calling node that calls the get_current_weather function.\n    "},
+            "comment": {
+                "expanded": True,
+                "value": "\n    A tool calling node that calls the get_current_weather function.\n    ",
+            },
         },
         "base": {
             "name": "ToolCallingNode",
@@ -150,7 +153,7 @@ def test_serialize_workflow():
                                             },
                                             {
                                                 "id": "1381c078-efa2-4255-89a1-7b4cb742c7fc",
-                                                "label": "StartNode",
+                                                "label": "Start Node",
                                                 "type": "GENERIC",
                                                 "display_data": {"position": {"x": 200.0, "y": -50.0}},
                                                 "base": {
