@@ -20,6 +20,7 @@ from vellum import (
 )
 from vellum.client.types.execute_prompt_event import ExecutePromptEvent
 from vellum.client.types.fulfilled_execute_prompt_event import FulfilledExecutePromptEvent
+from vellum.client.types.fulfilled_prompt_execution_meta import FulfilledPromptExecutionMeta
 from vellum.client.types.initiated_execute_prompt_event import InitiatedExecutePromptEvent
 from vellum.client.types.prompt_output import PromptOutput
 from vellum.client.types.prompt_request_string_input import PromptRequestStringInput
@@ -662,3 +663,65 @@ def test_inline_prompt_node__dict_blocks_error(vellum_adhoc_prompt_client):
     # THEN the node should raise the correct NodeException
     assert excinfo.value.code == WorkflowErrorCode.INVALID_INPUTS
     assert "Failed to compile blocks" == str(excinfo.value)
+
+
+def test_inline_prompt_node__invalid_function_type():
+    """Test that the node raises an error when an invalid function type is passed."""
+
+    # GIVEN a node that has an invalid function type (not dict or callable)
+    class MyInlinePromptNode(InlinePromptNode):
+        ml_model = "gpt-4o"
+        blocks = []
+        prompt_inputs = {}
+        functions = ["not_a_function"]  # type: ignore
+
+    # WHEN the node is created
+    node = MyInlinePromptNode()
+
+    # THEN the node should raise a NodeException with the correct error code
+    with pytest.raises(NodeException) as excinfo:
+        list(node.run())
+
+    # AND the error should have the correct code and message
+    assert excinfo.value.code == WorkflowErrorCode.INVALID_INPUTS
+    assert "`not_a_function` is not a valid function definition" == str(excinfo.value)
+
+
+def test_inline_prompt_node__empty_string_output_with_length_finish_reason(vellum_adhoc_prompt_client):
+    """
+    Tests that InlinePromptNode raises NodeException for empty string output with LENGTH finish_reason.
+    """
+
+    # GIVEN an InlinePromptNode with basic configuration
+    class TestNode(InlinePromptNode):
+        ml_model = "test-model"
+        blocks = []
+        prompt_inputs = {}
+
+    expected_outputs: List[PromptOutput] = [
+        StringVellumValue(value=""),
+    ]
+
+    def generate_prompt_events(*args: Any, **kwargs: Any) -> Iterator[ExecutePromptEvent]:
+        execution_id = str(uuid4())
+        events: List[ExecutePromptEvent] = [
+            InitiatedExecutePromptEvent(execution_id=execution_id),
+            FulfilledExecutePromptEvent(
+                execution_id=execution_id,
+                outputs=expected_outputs,
+                meta=FulfilledPromptExecutionMeta(finish_reason="LENGTH"),
+            ),
+        ]
+        yield from events
+
+    vellum_adhoc_prompt_client.adhoc_execute_prompt_stream.side_effect = generate_prompt_events
+
+    # WHEN the node is run
+    node = TestNode()
+
+    # THEN it should raise a NodeException with INVALID_OUTPUTS error code
+    with pytest.raises(NodeException) as excinfo:
+        list(node.run())
+
+    # AND the exception should have the correct error code
+    assert excinfo.value.code == WorkflowErrorCode.INVALID_OUTPUTS
