@@ -68,7 +68,7 @@ def compile_annotation(annotation: Optional[Any], defs: dict[str, Any]) -> dict:
             }
             return result
 
-    if dataclasses.is_dataclass(annotation):
+    if dataclasses.is_dataclass(annotation) and isinstance(annotation, type):
         if annotation.__name__ not in defs:
             properties = {}
             required = []
@@ -89,6 +89,10 @@ def compile_annotation(annotation: Optional[Any], defs: dict[str, Any]) -> dict:
                 # Mypy is incorrect here, the `annotation` attribute is defined on `FieldInfo`
                 field_annotation = field.annotation  # type: ignore[attr-defined]
                 properties[field_name] = compile_annotation(field_annotation, defs)
+
+                if hasattr(field, "description") and field.description is not None:
+                    properties[field_name]["description"] = field.description  # type: ignore[attr-defined]
+
                 if field.default is PydanticUndefined:
                     required.append(field_name)
                 else:
@@ -221,7 +225,7 @@ def compile_workflow_deployment_function_definition(
     deployment = deployment_config["deployment"]
     release_tag = deployment_config["release_tag"]
 
-    workflow_deployment_release = vellum_client.release_reviews.retrieve_workflow_deployment_release(
+    workflow_deployment_release = vellum_client.workflow_deployments.retrieve_workflow_deployment_release(
         deployment, release_tag
     )
 
