@@ -4,7 +4,7 @@ from enum import Enum
 from unittest.mock import Mock
 from typing import Annotated, Dict, List, Literal, Optional, Tuple, Union
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
 from vellum.client.types.function_definition import FunctionDefinition
 from vellum.client.types.string_vellum_value import StringVellumValue
@@ -206,7 +206,7 @@ def test_compile_function_definition__dataclasses():
 def test_compile_function_definition__pydantic():
     # GIVEN a function with a pydantic model
     class MyPydanticModel(BaseModel):
-        a: int
+        a: int = Field(description="The first number")
         b: str
 
     def my_function(c: MyPydanticModel):
@@ -225,7 +225,10 @@ def test_compile_function_definition__pydantic():
             "$defs": {
                 "MyPydanticModel": {
                     "type": "object",
-                    "properties": {"a": {"type": "integer"}, "b": {"type": "string"}},
+                    "properties": {
+                        "a": {"type": "integer", "description": "The first number"},
+                        "b": {"type": "string"},
+                    },
                     "required": ["a", "b"],
                 }
             },
@@ -448,7 +451,7 @@ def test_compile_workflow_deployment_function_definition__just_name():
     mock_release = Mock()
     mock_release.workflow_version.input_variables = []
     mock_release.description = "This is a test deployment"
-    mock_client.release_reviews.retrieve_workflow_deployment_release.return_value = mock_release
+    mock_client.workflow_deployments.retrieve_workflow_deployment_release.return_value = mock_release
 
     deployment_config = {"deployment": "my_deployment", "release_tag": "latest"}
 
@@ -494,7 +497,7 @@ def test_compile_workflow_deployment_function_definition__all_args():
 
     mock_release.workflow_version.input_variables = mock_inputs
     mock_release.description = "This is a test deployment"
-    mock_client.release_reviews.retrieve_workflow_deployment_release.return_value = mock_release
+    mock_client.workflow_deployments.retrieve_workflow_deployment_release.return_value = mock_release
 
     deployment_config = {"deployment": "my_deployment", "release_tag": "latest"}
 
@@ -562,7 +565,7 @@ def test_compile_workflow_deployment_function_definition__defaults():
 
     mock_release.workflow_version.input_variables = mock_inputs
     mock_release.description = "This is a test deployment"
-    mock_client.release_reviews.retrieve_workflow_deployment_release.return_value = mock_release
+    mock_client.workflow_deployments.retrieve_workflow_deployment_release.return_value = mock_release
 
     deployment_config = {"deployment": "my_deployment", "release_tag": "latest"}
 
